<?php
/**
 * sonus functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package sonus
*/

/**************************************************************************************************/
/* Define Constants */
/**************************************************************************************************/
define('SONUS_THEMEROOT', get_template_directory_uri());
define('SONUS_IMAGES', SONUS_THEMEROOT . '/framework/assets/images');

/**************************************************************************************************/
/* Theme Setup  */
/**************************************************************************************************/
add_action( 'after_setup_theme', 'sonus_setup' );
function sonus_setup(){
    global $content_width;
    if ( ! isset( $content_width ) ) $content_width = 1200;
    if ( function_exists( 'add_theme_support' ) ) {
        add_theme_support( 'post-thumbnails' );
            set_post_thumbnail_size( 848, 400, true);
    }
    add_theme_support( 'custom-logo' );
    load_theme_textdomain( 'sonus', get_template_directory().'/framework/languages' );
    add_action('init', 'sonus_register_menus');
    add_theme_support( 'automatic-feed-links' );
    add_editor_style('framework/assets/css/editor-style.css');
    add_theme_support( 'title-tag' );
    add_theme_support( 'post-formats', array('audio', 'image', 'gallery', 'video', 'quote', 'link', 'aside'));
}

/**************************************************************************************************/
/* Admin Framework  */
/**************************************************************************************************/

if ( file_exists( get_template_directory() . '/framework/sonus-config.php' ) ) {
    require_once( get_template_directory() . '/framework/sonus-config.php' );
}
/** remove redux menu under the tools **/
add_action( 'admin_menu', 'sonus_remove_redux_menu',12 );
function sonus_remove_redux_menu() {
    remove_submenu_page('tools.php','redux-about');
}

/**************************************************************************************************/
/* Include Meta Box  */
/**************************************************************************************************/
define( 'RWMB_URL', trailingslashit( get_template_directory_uri() . '/framework/meta-box' ) );
define( 'RWMB_DIR', trailingslashit( get_template_directory() . '/framework/meta-box' ) );
require_once RWMB_DIR . 'meta-box.php';
include_once get_template_directory() . '/framework/metabox.php';

/**************************************************************************************************/
/* TGM plugin activation */
/**************************************************************************************************/
include_once( get_template_directory() . '/framework/tgm/class-tgm-plugin-activation.php' );
include_once( get_template_directory() . '/framework/tgm/tgm-config.php' );



if (!function_exists('sonus_register_sidebars')){
    function sonus_register_sidebars() {
        if (function_exists('register_sidebar')) {
            register_sidebar(
                array(
                'name' => esc_html__( 'Main Sidebar', 'sonus' ),
                'id' => 'sidebar-1',
                'description' => esc_html__( 'Default Sidebar for all blog pages.', 'sonus' ),
                'before_widget' => '<div class="sidebar-widget">',
                'after_widget' => '</div>',
                'before_title' => '<div class="widget-title-cover"><h5>',
                'after_title' => '</h5></div>',
            ));
            register_sidebar(
                array(
                'name' => esc_html__( 'First Footer Column', 'sonus' ),
                'id' => 'footer-1',
                'description' => esc_html__( 'This sidebar for footers first column.', 'sonus' ),
                'before_widget' => '<div class="footer-widget">',
                'after_widget' => '</div>',
                'before_title' => '<div class="widget-title-cover"><h5>',
                'after_title' => '</h5></div>',
            ));
            register_sidebar(
                array(
                'name' => esc_html__( 'Second Footer Column', 'sonus' ),
                'id' => 'footer-2',
                'description' => esc_html__( 'This sidebar for footers second column.', 'sonus' ),
                'before_widget' => '<div class="footer-widget">',
                'after_widget' => '</div>',
                'before_title' => '<div class="widget-title-cover"><h5>',
                'after_title' => '</h5></div>',
            ));
            register_sidebar(
                array(
                'name' => esc_html__( 'Third Footer Column', 'sonus' ),
                'id' => 'footer-3',
                'description' => esc_html__( 'This sidebar for footers third column.', 'sonus' ),
                'before_widget' => '<div class="footer-widget">',
                'after_widget' => '</div>',
                'before_title' => '<div class="widget-title-cover"><h5>',
                'after_title' => '</h5></div>',
            ));
            register_sidebar(
                array(
                'name' => esc_html__( 'Fourth Footer Column', 'sonus' ),
                'id' => 'footer-4',
                'description' => esc_html__( 'This sidebar for footers fourth column.', 'sonus' ),
                'before_widget' => '<div class="footer-widget">',
                'after_widget' => '</div>',
                'before_title' => '<div class="widget-title-cover"><h5>',
                'after_title' => '</h5></div>',
            ));
            register_sidebar(
                array(
                'name' => esc_html__( 'Sidebar Podcast', 'sonus' ),
                'id' => 'sidebar-podcast',
                'description' => esc_html__( 'This sidebar for Podcast Single.', 'sonus' ),
                'before_widget' => '<div class="sidebar-widget">',
                'after_widget' => '</div>',
                'before_title' => '<div class="widget-title-cover"><h5>',
                'after_title' => '</h5></div>',
            ));
        }
    }
    add_action( 'widgets_init', 'sonus_register_sidebars');
}

global $sonus_opt;
if($sonus_opt['podcast-mode'] == 1){
function sonus_rename_podcast_format($sonus_format){
    if ( $sonus_format == 'Aside' )
        return 'Podcast';
    return $sonus_format;
}
add_filter( 'esc_html', 'sonus_rename_podcast_format' );
}
/**************************************************************************************************/
/* Register Menu */
/**************************************************************************************************/
function sonus_register_menus() {
    register_nav_menus( array( 'main-menu' => esc_html__('Main Menu',"sonus")) );
    register_nav_menus( array( 'mobile-menu' => esc_html__('Mobile Menu',"sonus")) );
}

/**************************************************************************************************/
/* Required Files */
/**************************************************************************************************/
include_once get_template_directory() . '/framework/customcss.php';
include_once get_template_directory() . '/framework/customjs.php';
require_once get_template_directory() . '/framework/pagination.php';
/**************************************************************************************************/
/* Custom Image Size */
/**************************************************************************************************/
if ( function_exists( 'add_image_size' ) ) {
    add_image_size( 'sonus-header-background', 1920, 600, true );
    add_image_size( 'sonus-profile-picture', 300, 300, true );
    add_image_size( 'sonus-podcast-cover', 730, 730, true );
    add_image_size( 'sonus-blog-thumbnail', 490, 460, true );
    add_image_size( 'sonus-blog-single', 1150, 0, true );
    add_image_size( 'sonus-blog-single', 1150, 0, true );
    add_image_size( 'sonus-blog-shortcode', 720, 400, true );
    add_image_size( 'sonus-widget-background', 720, 300, true );
}

function sonus_get_avatar_url($author_id, $size){
    $get_avatar = get_avatar( $author_id, $size );
    preg_match("/src='(.*?)'/i", $get_avatar, $matches);
    return ( $matches[1] );
}

/**************************************************************************************************/
/* Register Css & Js  */
/**************************************************************************************************/
function sonus_register_files(){
    //css
    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/framework/assets/css/bootstrap.min.css', null, null);
    if(is_rtl()){
        wp_register_style('bootstrap-rtl', get_template_directory_uri() . '/framework/assets/css/bootstrap.rtl.min.css', null, null); 
        wp_enqueue_style('bootstrap-rtl');
    }
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/framework/assets/css/font-awesome.min.css', null, null);
    wp_enqueue_style('mediaelementplayer', get_template_directory_uri() . '/framework/assets/css/mediaelementplayer.min.css', null, null);
    wp_enqueue_style('sonus-main', get_stylesheet_uri());
    if (is_rtl()){
        wp_register_style('sonus-rtl', get_template_directory_uri() . '/framework/assets/css/sonus-rtl.css', null, null); 
        wp_enqueue_style('sonus-rtl');
    }
    wp_enqueue_style('responsive', get_template_directory_uri() . '/framework/assets/css/sonus-responsive.css', null, null);
    //js
    $ajaxPath = array('ajaxUrl' => get_template_directory_uri().'/framework/newsletter-session.php');
    wp_enqueue_script('modernizr', get_template_directory_uri() . '/framework/assets/js/modernizr-respond.min.js', null, true);
    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/framework/assets/js/bootstrap.min.js', array('jquery'), null, true);
    wp_enqueue_script('superfishpack', get_template_directory_uri() . '/framework/assets/js/superfish.pack.1.4.1.js', array('jquery'), null, true);
    wp_enqueue_script('slimscroll', get_template_directory_uri() . '/framework/assets/js/jquery.slimscroll.min.js', array('jquery'), null, true);
    wp_enqueue_script('mediaelementplayer', get_template_directory_uri() . '/framework/assets/js/mediaelement-and-player.min.js', array('jquery'), null, true);
    wp_enqueue_script('fitvids', get_template_directory_uri() . '/framework/assets/js/jquery.fitvids.js', array('jquery'), null, true);
    if(is_singular()) wp_enqueue_script('comment-reply');
    wp_enqueue_script('sonus-main', get_template_directory_uri() . '/framework/assets/js/sonus-main.js', array('jquery'), null, true);
    wp_localize_script('sonus-main', 'ajaxPath', $ajaxPath);
}
add_action('wp_enqueue_scripts', 'sonus_register_files');

if (is_admin()){
    function sonus_admin_files(){
        wp_enqueue_script('sonus-admin-js', get_template_directory_uri() . '/framework/assets/js/admin/sonus-init.js', array('jquery'), null, true);
        wp_enqueue_media();
        wp_enqueue_script('sonus-admin-upload', get_template_directory_uri() . '/framework/assets/js/admin/sonus-upload-media.js', array('jquery'), null, true);
        wp_enqueue_style('sonus-admin-css', get_template_directory_uri() . '/framework/assets/css/sonus-admin.css', null, null);
    }
}
add_action('admin_enqueue_scripts', 'sonus_admin_files');

function sonus_register_session(){
    if( !session_id() )
    session_start();
}
add_action('init','sonus_register_session');

function sonus_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt);
  } else {
    $excerpt = implode(" ",$excerpt);
  } 
  $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
  return $excerpt;
}

function sonus_is_podcast($checkpost){
    $post_format = get_post_format($checkpost);
    if($post_format == "aside"){ return true; }else{ return false; }
}

function sonus_comment_form_edit( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter('comment_form_fields', 'sonus_comment_form_edit');

function sonus_post_format_filter($query){
    global $sonus_opt;
    if($sonus_opt['podcast-mode'] == 1){
        if($query->is_home() && $query->is_main_query()){
            global $wp_query;
            $post_format_tax_query = array(
                'taxonomy' => 'post_format',
                'field' => 'slug',
                'terms' => 'post-format-aside',
                'operator' => 'NOT IN'
            );
            $tax_query = $wp_query->get('tax_query');
            if(is_array($tax_query)){
                $tax_query = $tax_query + $post_format_tax_query;
            }else{
                $tax_query = array($post_format_tax_query);
            }
            $wp_query->set('tax_query', $tax_query);
        }
    }
}
add_action('pre_get_posts', 'sonus_post_format_filter');

/**************************************************************************************************/
/* Custom Comments */
/**************************************************************************************************/

function sonus_comment( $comment, $args, $depth ) {
       $GLOBALS['comment'] = $comment; ?>                    
        <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
            <div id="comment-<?php comment_ID(); ?>" class="clearfix"> 
                <div class="user-comment-box clearfix">
                    <div class="row">
                        <div class="col-lg-12">
                            <?php
                                $check_comment = get_avatar($comment);
                                if($check_comment){
                                    $left_classes = "comment-left-image pull-left";
                                    $right_classes = "comment-right-text pull-left comment-content";
                                }else{
                                    $right_classes = "comment-content";
                                }
                            ?>
                            <div class="comment-info-top clearfix<?php if($check_comment){echo " with-userimage";} ?>">
                                <?php if($check_comment){ ?>
                                <div class="<?php echo esc_attr($left_classes); ?>">
                                    <?php echo get_avatar( $comment, 70, null, null, array('class' => array('img-responsive'))); ?>
                                </div>
                                <?php } ?>
                                <div class="<?php echo esc_attr($right_classes); ?>">
                                    <div class="clearfix">
                                         <div class="author author-title">
                                            <h3><?php printf( esc_html__( '%s', 'sonus'), get_comment_author_link() ) ?></h3>
                                         </div>
                                         <a class="element-date date" title="<?php echo esc_attr($post_date = get_comment_date('F j, Y g:i')); ?>" href="<?php the_permalink(); ?>"><?php echo esc_attr($post_date = get_comment_date()); ?></a>
                                     </div>
                                </div>
                            </div>
                            <div class="comment-area-box<?php if($check_comment){echo " with-userimage";} ?>">
                                <div class="comment-text margint10 clearfix<?php if(is_user_logged_in()){ echo " cuser-in"; } ?>">
                                    <div class="pull-left comment-text-box"><?php comment_text(); ?></div>
                                    <div class="pull-left comment-tools">
                                        <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?><?php edit_comment_link( esc_html__( ' (Edit)', 'sonus'),'  ','' ) ?>
                                     </div>
                                </div>
                                 <?php if ( $comment->comment_approved == '0' ) : ?>
                                 <em><?php esc_html__( 'Your comment is awaiting moderation.', 'sonus' ) ?></em>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </li>
<?php }

if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
    wp_enqueue_script( 'comment-reply' );

function sonus_add_meta_fields( $taxonomy ) { ?>
    <div class="form-field term-group">
        <label for="season">
          <?php echo __('Season', 'sonus'); ?> <input type="checkbox" id="season" name="season" value="yes" />
        </label>
    </div><?php
}
add_action( 'category_add_form_fields', 'sonus_add_meta_fields', 10, 2 );

// Edit term page
function sonus_edit_meta_fields( $term, $taxonomy ) {
    $season = get_term_meta( $term->term_id, 'season', true ); ?>

    <tr class="form-field term-group-wrap">
        <th scope="row">
            <label for="season"><?php echo __('Season', 'sonus'); ?></label>
        </th>
        <td>
            <input type="checkbox" id="season" name="season" value="yes" <?php echo ( $season ) ? checked( $season, 'yes' ) : ''; ?>/>
        </td>
    </tr><?php
}
add_action( 'category_edit_form_fields', 'sonus_edit_meta_fields', 10, 2 );

function sonus_save_taxonomy_meta( $term_id, $tag_id ) {
    if ( isset( $_POST[ 'season' ] ) ) {
        update_term_meta( $term_id, 'season', 'yes' );
    } else {
        update_term_meta( $term_id, 'season', '' );
    }
}
add_action( 'created_category', 'sonus_save_taxonomy_meta', 10, 2 );
add_action( 'edited_category', 'sonus_save_taxonomy_meta', 10, 2 );

function sonus_breadcrumb() {
    $sep = '<span class="breadcrumb-seperator"> > </span>';
    if (!is_front_page()) {
        echo '<div class="sonus-breadcrumbs">';
        echo '<a href="';
        echo esc_url(home_url('/'));;
        echo '">';
        echo __('Home', 'sonus');
        echo '</a>' . $sep;
        if (is_category() || is_single() ){
            the_category(', ');
        } elseif (is_archive() || is_single()){
            echo __('Blog Archives', 'sonus');
        }
        if(is_single()){
        }
        if(is_page()){
            echo the_title();
        }
        if (is_home()){
            global $post;
            $page_for_posts_id = get_option('page_for_posts');
            if ( $page_for_posts_id ) { 
                $post = get_page($page_for_posts_id);
                setup_postdata($post);
                the_title();
                rewind_posts();
            }
        }
        echo '</div>';
    }
}
?>